@@ -1,6 +1,8 @@
 import os
 from dotenv import load_dotenv
 
+#print('loading environment variables...')
+
 load_dotenv()  # take environment variables from .env.
 
 if not 'DATABASE_FOLDER' in os.environ:    
@@ -22,3 +24,5 @@ if not 'BASE_STREAM_NAME' in os.environ:
     os.environ['BASE_STREAM_NAME'] = 'deepportfolio-real-time'
 
 os.environ['USER_COMPUTER'] = os.environ['USERNAME']+'@'+os.environ['COMPUTERNAME']
+
+loaded=True
\ No newline at end of file
