@@ -10,7 +10,7 @@ import boto3
 
 from importlib.metadata import version
 
-import SharedData.Defaults 
+import SharedData.Defaults as Defaults 
 from SharedData.SharedDataAWSKinesis import KinesisLogStreamHandler
 
 
@@ -19,7 +19,9 @@ class Logger:
     log = None
 
     def __init__(self, source):
-        # os.environ['PATH'] = os.environ['PATH']+';'+';'.join(sys.path)
+        if Defaults.loaded:
+            pass
+            #print('loading environment variables Done!')
                 
         if 'SOURCE_FOLDER' in os.environ:
             try:
