@@ -67,18 +67,19 @@ class SharedDataRealTime:
     
     def Subscribe(shdata):
         today = pd.Timestamp(pd.Timestamp.now().date())
-        if not shdata['RT']['D1'].exists(today):
+        wd = shdata['RT/Watchdog']['D1']
+        if not wd.exists(today):
             df = pd.DataFrame(
                 0,
                 index = ['MarketData','Signals','Porfolios'],
                 columns = ['watchdog']
             )
-            df.loc[shdata.database,'watchdog'] = time.time() - 61
-            shdata['RT']['D1'][today] = df
-            shdata['RT']['D1'].tags[today].Write()
+            df.loc[shdata.database,'watchdog'] = time.time() - 20
+            wd[today] = df
+            wd.tags[today].Write()
         
         # start subprocess if 
-        df = shdata['RT']['D1'][today]
+        df = wd[today]
         if time.time() - df.loc[shdata.database,'watchdog'] > 15:
             proc = subprocess.Popen(['python','-m',\
                 'SharedData.SharedDataRealTimeProcess'],
